@@ -39,20 +39,20 @@ if __name__ == '__main__':
 	del(r.a, r['b'])
 
 	# test for more data structure
-	print('\n\n-------Test without numpy & pandas----------\n')
+	print('\n\n-------Test without numpy & pandas----------')
 	r.avec = 0, 1, 2, 3, 4
 	r.alist = [1, (2, 3, 'any strings'), 4+5j]
 	r('amat <- matrix(0:11, nrow=3, byrow=TRUE)')
 	r('aary <- array(0:23, dim=c(3,4,2))')
 	r('adfm <- data.frame(aa=1:3, bb=paste("s", 2:4, sep="-"))')
-	print('R vector (avec): ' + repr(r.avec))
-	print('R list (alist): ' + repr(r.alist))
-	print('R matrix (amat): ' + repr(r.amat))
-	print('R array (aary): ' + repr(r.aary))
-	print('R data frame (adfm): ' + repr(r.adfm))
+	print('\nR vector (avec): \n' + repr(r.avec))
+	print('\nR list (alist): \n' + repr(r.alist))
+	print('\nR matrix (amat): \n' + repr(r.amat))
+	print('\nR array (aary): \n' + repr(r.aary))
+	print('\nR data frame (adfm): \n' + repr(r.adfm))
 
 	if has_numpy:
-		print('\n\n-------Test with numpy----------\n')
+		print('\n\n-------Test with numpy----------')
 		r.has_numpy = True
 		arange, array, reshape = numpy.arange, numpy.array, numpy.reshape
 		# numpy arrays
@@ -65,21 +65,21 @@ if __name__ == '__main__':
 		# one-dimenstion numpy record array will be converted to R data.framme
 		r.bdfm = array([(1, 'Joe', 35820.0), (2, 'Jane', 41235.0), (3, 'Kate', 37932.0)], \
 				dtype=[('id', '<i4'), ('employee', '|S4'), ('salary', '<f4')])
-		print('R vector (avec): ' + repr(r['avec']))
-		print('R vector (bvec): ' + repr(r['bvec']))
-		print('R matrix (amat): ' + repr(r['amat']))
-		print('R matrix (bamat): ' + repr(r['bmat']))
-		print('R array (aary): ' + repr(r['aary']))
-		print('R array (bary): ' + repr(r['bary']))
-		print('R data frame (adfm): ' + repr(r['adfm']))
-		print('R data frame (bdfm): ' + repr(r['bdfm']))
+		print('\nR vector (avec): \n' + repr(r['avec']))
+		print('\nR vector (bvec): \n' + repr(r['bvec']))
+		print('\nR matrix (amat): \n' + repr(r['amat']))
+		print('\nR matrix (bamat): \n' + repr(r['bmat']))
+		print('\nR array (aary): \n' + repr(r['aary']))
+		print('\nR array (bary): \n' + repr(r['bary']))
+		print('\nR data frame (adfm): \n' + repr(r['adfm']))
+		print('\nR data frame (bdfm): \n' + repr(r['bdfm']))
 
 	if has_pandas:
-		print('\n\n-------Test with pandas----------\n')
+		print('\n\n-------Test with pandas----------')
 		r.has_pandas = True
-		print('R data frame (adfm): ' + repr(r.adfm))
+		print('\nR data frame (adfm): \n' + repr(r.adfm))
 		if has_numpy:
-			print('R data frame (bdfm): ' + repr(r['bdfm']))
+			print('\nR data frame (bdfm): \n' + repr(r['bdfm']))
 
 
 	# test huge data sets and the function runR
